---
title: "getNumberFormatterSource"
parent: "@messageformat/number-skeleton"
grand_parent: API Reference
---

<!-- Do not edit this file. It is automatically generated by API Documenter. -->



# getNumberFormatterSource() function

Returns a string of JavaScript source that evaluates to a number formatter function with the same `(value: number) => string` signature as the function returned by [getNumberFormatter()](./number-skeleton.getnumberformatter.md)<!-- -->.

<b>Signature:</b>

```typescript
export declare function getNumberFormatterSource(locales: string | string[], skeleton: string | Skeleton, currency?: string | null, onError?: (err: NumberFormatError) => void): string;
```

## Parameters

|  Parameter | Type | Description |
|  --- | --- | --- |
|  locales | string \| string\[\] | One or more valid BCP 47 language tags, e.g. <code>fr</code> or <code>en-CA</code> |
|  skeleton | string \| [Skeleton](./number-skeleton.skeleton.md) | An ICU NumberFormatter pattern or <code>::</code>-prefixed skeleton string, or a parsed <code>Skeleton</code> structure |
|  currency | string \| null | If <code>skeleton</code> is a pattern string that includes ¤ tokens, their skeleton representation requires a three-letter currency code. |
|  onError | (err: [NumberFormatError](./number-skeleton.numberformaterror.md)<!-- -->) =&gt; void | If defined, will be called separately for each encountered parsing error and unsupported feature. |

<b>Returns:</b>

string

## Remarks

The returned function will memoize an `Intl.NumberFormat` instance that makes use of features provided by the [Unified API Proposal](https://github.com/tc39/proposal-unified-intl-numberformat)<!-- -->.

## Example


```js
import { getNumberFormatterSource } from '@messageformat/number-skeleton'

getNumberFormatterSource('en', '::percent', console.error)
// '(function() {\n' +
// '  var opt = {"style":"percent"};\n' +
// '  var nf = new Intl.NumberFormat(["en"], opt);\n' +
// '  var mod = function(n) { return n * 0.01; };\n' +
// '  return function(value) { return nf.format(mod(value)); }\n' +
// '})()'

const src = getNumberFormatterSource('en-CA', ':: currency/CAD unit-width-narrow', console.error)
// '(function() {\n' +
// '  var opt = {"style":"currency","currency":"CAD","currencyDisplay":"narrowSymbol","unitDisplay":"narrow"};\n' +
// '  var nf = new Intl.NumberFormat(["en-CA"], opt);\n'
// '  return function(value) { return nf.format(value); }\n' +
// '})()'
const fmt = new Function(`return ${src}`)()
fmt(42) // '$42.00'

```

